<?php
function add_blog_idea_actions($actions, $post) {
    if ($post->post_type === 'blog_idea') {
		
		// Add View, Edit, Delete
        $view_link = get_permalink($post->ID);
        $edit_link = get_edit_post_link($post->ID);
        $delete_link = get_delete_post_link($post->ID);

        $actions['view'] = '<a href="' . esc_url($view_link) . '" target="_blank">View</a>';
        $actions['edit'] = '<a href="' . esc_url($edit_link) . '">Edit</a>';
        $actions['delete'] = '<a href="' . esc_url($delete_link) . '" onclick="return confirm(\'Are you sure you want to delete this idea?\')">Delete</a>';

		//Add convert to post
        $url = admin_url('admin-post.php?action=convert_blog_idea_to_post&post_id=' . $post->ID);
        $actions['convert_to_post'] = '<a href="' . esc_url($url) . '">Convert to Post</a>';
    }
    return $actions;
}
add_filter('post_row_actions', 'add_blog_idea_actions', 10, 2);

//Convert idea to post from link
function handle_blog_idea_conversion() {
    if (!isset($_GET['post_id']) || !current_user_can('edit_posts')) {
        wp_die('Unauthorized action');
    }
    
    $blog_idea_id = intval($_GET['post_id']);
    $blog_idea = get_post($blog_idea_id);

    if (!$blog_idea || $blog_idea->post_type !== 'blog_idea') {
        wp_die('Invalid Blog Idea');
    }

    $new_post_data = array(
        'post_title'   => $blog_idea->post_title,
        'post_content' => $blog_idea->post_content,
        'post_status'  => 'draft',
        'post_type'    => 'post',
        'post_author'  => $blog_idea->post_author,
    );

    $new_post_id = wp_insert_post($new_post_data);

    if (is_wp_error($new_post_id)) {
        wp_die('Error converting Blog Idea to Post');
    }

    // Copy metadata
    $meta_data = get_post_meta($blog_idea_id);
    foreach ($meta_data as $key => $value) {
        update_post_meta($new_post_id, $key, maybe_unserialize($value[0]));
    }

    // Copy taxonomies
    $taxonomies = get_object_taxonomies('blog_idea');
    foreach ($taxonomies as $taxonomy) {
        $terms = wp_get_post_terms($blog_idea_id, $taxonomy, array('fields' => 'slugs'));
        wp_set_post_terms($new_post_id, $terms, $taxonomy);
    }

    // Delete the original Blog Idea post
    wp_delete_post($blog_idea_id, true);

    wp_redirect(admin_url('edit.php?post_type=blog_idea&message=converted'));
    exit;
}
add_action('admin_post_convert_blog_idea_to_post', 'handle_blog_idea_conversion');

function add_conversion_notice() {
    if (isset($_GET['message']) && $_GET['message'] === 'converted') {
        echo '<div class="notice notice-success is-dismissible">
                <p>Blog Idea successfully converted to a post!</p>
              </div>';
    }
}
add_action('admin_notices', 'add_conversion_notice');


function handle_idea_conversion_from_edit($post_id) {
    // Check if this is an auto-save or a revision
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    // Verify if user clicked the Convert button
    if (isset($_POST['convert_idea'])) {

        // Check permissions: user must be able to edit posts
        if (!current_user_can('edit_blog_idea', $post_id)) {
            return;
        }
        
        // Verify nonce
        if (!isset($_POST['convert_idea_nonce']) ||
            !wp_verify_nonce($_POST['convert_idea_nonce'], 'convert_idea_action')) {
            return;
        }

        // Make sure the post type is 'blog_idea'
        $post_type = get_post_type($post_id);
        if ($post_type !== 'blog_idea') {
            return;
        }

        // Update the post’s type and status
        $updated_post = array(
            'ID'          => $post_id,
            'post_type'   => 'post',   // convert to standard WP post
            'post_status' => 'draft'   // set status to draft
        );
        wp_update_post($updated_post);
    }
}
add_action('save_post_idea', 'handle_idea_conversion_from_edit');
