<?php

function blog_ideas_deactivate() {
    remove_unassigned_workflow_statuses();
	remove_blog_idea_capabilities();
}

function remove_unassigned_workflow_statuses() {
    $statuses = get_blog_ideas_default_workflow_statuses();
    $taxonomy = 'idea_status';
    $deleted_statuses = array();

    foreach ($default_statuses as $status) {
        $term = get_term_by('name', $status, $taxonomy);

        if ($term) {
            // Query to check if any idea uses this status
            $query = new WP_Query(array(
                'post_type' => 'blog_idea',
                'tax_query' => array(
                    array(
                        'taxonomy' => $taxonomy,
                        'field' => 'term_id',
                        'terms' => $term->term_id,
                    ),
                ),
            ));

            // If unassigned, delete the term and add to deleted list
            if ($query->found_posts === 0) {
                wp_delete_term($term->term_id, $taxonomy);
                $deleted_statuses[] = $status;
            }
        }
    }

    // If there are deleted statuses, display an admin notice
    if (!empty($deleted_statuses)) {
        update_option('deleted_blog_idea_workflow_statuses', $deleted_statuses); // Save for admin notice
    }
}

function remove_blog_idea_capabilities() {
	$capabilities = get_blog_idea_capabilities();
    $editor_role = get_role('editor');
	$admin_role = get_role('administrator');
	
	if ($admin_role) {
		// remove capabilities for managing blog ideas for admin
        foreach ($capabilities as $cap) {
            $admin_role->remove_cap($cap);
        }
    }
	if ($editor_role) {
		// remove capabilities for managing blog ideas for editor
        foreach ($capabilities as $cap) {
            $editor_role->remove_cap($cap);
        }
    }
}