<?php
/*
 * Adding blog ideas functionality
 * */
function register_blog_ideas_cpt() {
    $args = array(
        'labels' => array(
            'name' => 'Blog Ideas',
            'singular_name' => 'Blog Idea',
            'add_new' => 'Add New Idea',
			'add_new_item' => 'Add New Idea',
            'edit_item' => 'Edit Idea',
            'new_item' => 'New Idea',
            'view_item' => 'View Idea',
            'search_items' => 'Search Ideas',
            'not_found' => 'No Ideas Found',
            'not_found_in_trash' => 'No Ideas Found in Trash',
			'all_items' => 'All Ideas',
			'archives' => 'Idea Archives',
			'insert_into_item' => 'Insert into Idea',
			'uploaded_to_this_item' => 'Uploaded to this Idea',
			'filter_items_list' => 'Filter Ideas list',
			'items_list_navigation' => 'Ideas list navigation',
			'items_list' => 'Ideas list',
        ),
        'public' => false, //not visible to the front end
		'show_ui' => true,  //allow managing in the admin interface
        'supports' => array('title', 'editor','custom-fields'),
        'has_archive' => true,
        'menu_icon' => 'dashicons-lightbulb',
		'capability_type' => 'blog_idea', //custom capability type definition
		'map_meta_cap' => true,//enable meta capabilities for finer control
    );
    register_post_type('blog_idea', $args);
}
add_action('init', 'register_blog_ideas_cpt');


function blog_idea_meta_boxes(){
	add_meta_box(
		'blog_idea_details',
		'Blog Idea Details',
		'render_blog_idea_meta_box',
		'blog_idea',
		'normal',
		'default'
	);
	
	//Adding option to convert the idea to post in edit mode
	add_meta_box(
        'convert_idea_box',          // Meta box ID
        'Convert to Draft Post',     // Meta box Title
        'render_convert_idea_box',   // Callback function
        'blog_idea',                      // Post type where it’ll appear
        'side',                      // Context (sidebar, normal, advanced)
        'default'                    // Priority
    );
}
function render_blog_idea_meta_box($post) {
    $priority = get_post_meta($post->ID, 'priority', true);
    $keywords = get_post_meta($post->ID, 'keywords', true);
	
	// Idea priority options
    $priority_options = array(
        ''        => 'Select Priority',
        'Low'     => 'Low',
        'Medium'  => 'Medium',
        'High'    => 'High',
        'Urgent'  => 'Urgent',
    );
	
	wp_nonce_field('save_blog_idea_meta_box', 'blog_idea_meta_box_nonce');
    ?>
    <p>
        <label for="priority">Priority:</label><br>
        <select id="priority" name="priority" style="width: 100%;">
            <?php foreach ($priority_options as $value => $label) : ?>
                <option value="<?php echo esc_attr($value); ?>" <?php selected($priority, $value); ?>>
                    <?php echo esc_html($label); ?>
                </option>
            <?php endforeach; ?>
        </select>
    </p>
    <p>
        <label for="keywords">Keywords:</label><br>
        <textarea id="keywords" name="keywords" rows="3" style="width: 100%;"><?php echo esc_textarea($keywords); ?></textarea>
    </p>
    <?php
}

function render_convert_idea_box($post) {
    // Use a nonce for security
    wp_nonce_field('convert_idea_action', 'convert_idea_nonce');

    // Simple button in the sidebar
    echo '<p>';
    echo '<input type="submit" class="button button-primary" value="Convert to Draft Post" name="convert_idea">';
    echo '</p>';
}

function save_blog_idea_meta_boxes($post_id) {
	
	// Verify nonce
	if (!isset($_POST['blog_idea_meta_box_nonce']) || !wp_verify_nonce($_POST['blog_idea_meta_box_nonce'], 'save_blog_idea_meta_box')) {
		return;
	}
	
	if (!isset($_POST['priority']) || !isset($_POST['keywords'])) {
        return;
    }
	
	// Check user capabilities
    if (!current_user_can('edit_blog_idea', $post_id)) {
        return;
    }

    // Prevent auto-save from interfering
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
	
    if (array_key_exists('priority', $_POST)) {
        update_post_meta($post_id, 'priority', sanitize_text_field($_POST['priority']));
    }
    if (array_key_exists('keywords', $_POST)) {
        update_post_meta($post_id, 'keywords', sanitize_textarea_field($_POST['keywords']));
    }
}
add_action('add_meta_boxes', 'blog_idea_meta_boxes');
add_action('save_post', 'save_blog_idea_meta_boxes');

function add_blog_idea_columns($columns) {
    $columns['idea_status'] = 'Status';
    $columns['priority'] = 'Priority';
    return $columns;
}

function render_blog_idea_columns($column, $post_id) {
    if ($column == 'idea_status') {
        echo get_the_term_list($post_id, 'idea_status', '', ', ');
    }
    if ($column == 'priority') {
        echo get_post_meta($post_id, 'priority', true);
    }
}

add_filter('manage_blog_idea_posts_columns', 'add_blog_idea_columns');
add_action('manage_blog_idea_posts_custom_column', 'render_blog_idea_columns', 10, 2);

//redirect to idea listing on save_post
function redirect_after_publishing_blog_idea($post_id, $post, $update){
	//only apply to blog_idea post type
	if($post->post_type !== 'blog_idea'){
		return;
	}
	//check if status is publish
	if($post->post_status === 'publish'){
		wp_redirect(admin_url('edit.php?post_type=blog_idea'));
		exit;
	}
}
add_action('save_post','redirect_after_publishing_blog_idea',10,3);